
============
stimela 2.0
============


|Pypi Version|
|Python Versions|  

A workflow management framework for radio interometry data processing pipelines.

`Documentation Page <https://stimela.readthedocs.io/>`_  
=========================================================================================



.. |Pypi Version| image:: https://img.shields.io/pypi/v/stimela.svg
                  :target: https://pypi.python.org/pypi/stimela
                  :alt:


.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/stimela.svg
                     :target: https://pypi.python.org/pypi/stimela
                     :alt:
